# Legacy Software and Operating System Support Policy

It is the official policy of the Chia Blockchain project to end software support when the original maintainer of the software deems it End of Life (EOL) or stops providing support.  The most relevant targets of this policy are Python, Node.js, and operating systems.

## Long-term Support Conflicts

If a long-term support version of an operating system uses a default Python version that has lost official support, we also intend to end support for that operating system version, so as to avoid issues with installing a new Python version via Chia install, which may break crucial operating system components.

## More Information

For more information, please contact hello@chia.net or reach out on the community Discord.
